@@ -6,6 +6,9 @@ from django.utils.html import format_html
 from allianceauth.eveonline.models import EveCorporationInfo, EveAllianceInfo
 from allianceauth.services.hooks import get_extension_logger
 
+from app_utils.django import admin_boolean_icon_html
+from app_utils.logging import LoggerAddTag
+
 from . import __title__
 from .app_settings import STRUCTURES_DEVELOPER_MODE
 from .models import (
@@ -27,7 +30,6 @@ from .models import (
     Webhook,
 )
 from . import tasks
-from .utils import LoggerAddTag
 
 
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
@@ -93,34 +95,66 @@ if STRUCTURES_DEVELOPER_MODE:
         ]
 
 
+class RenderableNotificationFilter(admin.SimpleListFilter):
+    title = "can be send"
+
+    parameter_name = "notification_renderable"
+
+    def lookups(self, request, model_admin):
+        return (
+            ("yes", "Yes"),
+            ("no", "No"),
+        )
+
+    def queryset(self, request, queryset):
+        """Return the filtered queryset"""
+        if self.value() == "yes":
+            return queryset.annotate_can_be_rendered().filter(can_be_rendered_2=True)
+        elif self.value() == "no":
+            return queryset.annotate_can_be_rendered().filter(can_be_rendered_2=False)
+        else:
+            return queryset
+
+
 @admin.register(Notification)
 class NotificationAdmin(admin.ModelAdmin):
     list_display = (
         "notification_id",
         "owner",
-        "notification_type",
+        "notif_type",
         "timestamp",
         "created",
         "last_updated",
         "_webhooks",
-        "is_sent",
-        "is_timer_added",
+        "_is_sent",
+        "_is_timer_added",
     )
     ordering = ["-timestamp", "-notification_id"]
-    list_filter = ("owner", "notification_type", "is_sent")
+    list_filter = ("owner", RenderableNotificationFilter, "is_sent", "notif_type")
 
     def _webhooks(self, obj):
-        names = [x.name for x in obj.owner.webhooks.all().order_by("name")]
+        if not obj.can_be_rendered:
+            return format_html("<i>N/A</i>")
+        names = [
+            x.name
+            for x in obj.owner.webhooks.filter(
+                notification_types__contains=obj.notif_type
+            ).order_by("name")
+        ]
         if names:
             return ", ".join(names)
         else:
             return format_html(
-                '<span style="color: red"></i>Error: This notification can not be sent, '
-                "because there is no webhook configured for {}. ",
-                obj.owner,
+                '<b><span style="color: orange">Not configured</span></b>'
             )
 
-    _webhooks.short_description = "Webhooks"
+    def _is_sent(self, obj):
+        value = obj.is_sent if obj.can_be_rendered else None
+        return admin_boolean_icon_html(value)
+
+    def _is_timer_added(self, obj):
+        value = obj.is_timer_added if obj.can_have_timer else None
+        return admin_boolean_icon_html(value)
 
     actions = (
         "mark_as_sent",
@@ -156,14 +190,18 @@ class NotificationAdmin(admin.ModelAdmin):
     mark_as_unsent.short_description = "Mark selected notifications as unsent"
 
     def send_to_webhooks(self, request, queryset):
-        obj_pks = [obj.pk for obj in queryset]
+        obj_pks = [obj.pk for obj in queryset if obj.can_be_rendered]
+        ignored_count = len([obj for obj in queryset if not obj.can_be_rendered])
         tasks.send_notifications.delay(obj_pks)
-
-        self.message_user(
-            request,
-            "Initiated sending of {} notifications to "
-            "configured webhooks".format(len(obj_pks)),
+        message = (
+            f"Initiated sending of {len(obj_pks)} notification(s) to "
+            f"configured webhooks."
         )
+        if ignored_count:
+            message += (
+                f" Ignored {ignored_count} notification(s), which can not be rendered."
+            )
+        self.message_user(request, message)
 
     send_to_webhooks.short_description = (
         "Send selected notifications to configured webhooks"
@@ -171,16 +209,19 @@ class NotificationAdmin(admin.ModelAdmin):
 
     def process_for_timerboard(self, request, queryset):
         notifications_count = 0
+        ignored_count = 0
         for obj in queryset:
             if obj.process_for_timerboard():
                 notifications_count += 1
+            else:
+                ignored_count += 1
 
-        self.message_user(
-            request,
-            "Added timers from {} notifications to timerboard".format(
-                notifications_count
-            ),
+        message = (
+            f"Added timers from {notifications_count} notifications to timerboard."
         )
+        if ignored_count:
+            message += f" Ignored {ignored_count} notification(s), which has no relation to timers."
+        self.message_user(request, message)
 
     process_for_timerboard.short_description = (
         "Process selected notifications for timerboard"
@@ -249,6 +290,7 @@ class OwnerAdmin(admin.ModelAdmin):
         OwnerSyncStatusFilter,
     )
     ordering = ["corporation__corporation_name"]
+    search_fields = ["corporation__corporation_name"]
 
     def _ping_groups(self, obj):
         names = [x.name for x in obj.ping_groups.all().order_by("name")]
@@ -287,9 +329,9 @@ class OwnerAdmin(admin.ModelAdmin):
     _is_active.short_description = "active"
 
     def _is_alliance_main(self, obj):
-        return obj.is_alliance_main
+        value = True if obj.is_alliance_main else None
+        return admin_boolean_icon_html(value)
 
-    _is_alliance_main.boolean = True
     _is_alliance_main.short_description = "alliance main"
 
     def _is_structure_sync_ok(self, obj):
@@ -692,16 +734,19 @@ class WebhookAdmin(admin.ModelAdmin):
     ordering = ["name"]
     list_display = (
         "name",
-        "webhook_type",
-        "has_default_pings_enabled",
         "_ping_groups",
         "is_active",
-        "is_default",
+        "_is_default",
         "_messages_in_queue",
     )
-    list_filter = ("webhook_type", "has_default_pings_enabled", "is_active")
+    list_filter = ("is_active",)
     save_as = True
 
+    def _default_pings(self, obj):
+        return obj.has_default_pings_enabled
+
+    _default_pings.boolean = True
+
     def _ping_groups(self, obj):
         names = [x.name for x in obj.ping_groups.all().order_by("name")]
         if names:
@@ -709,6 +754,10 @@ class WebhookAdmin(admin.ModelAdmin):
         else:
             return None
 
+    def _is_default(self, obj):
+        value = True if obj.is_default else None
+        return admin_boolean_icon_html(value)
+
     def _messages_in_queue(self, obj):
         return obj.queue_size()
 
@@ -731,19 +780,18 @@ class WebhookAdmin(admin.ModelAdmin):
         for obj in queryset:
             obj.is_active = True
             obj.save()
+            self.message_user(request, f'You have activated webhook "{obj}"')
 
-            self.message_user(request, 'You have activated profile "{}"'.format(obj))
-
-    activate.short_description = "Activate selected profiles"
+    activate.short_description = "Activate selected webhook"
 
     def deactivate(self, request, queryset):
         for obj in queryset:
             obj.is_active = False
             obj.save()
 
-            self.message_user(request, 'You have de-activated profile "{}"'.format(obj))
+            self.message_user(request, f'You have de-activated webhook "{obj}"')
 
-    deactivate.short_description = "Deactivate selected profiles"
+    deactivate.short_description = "Deactivate selected webhook"
 
     def purge_messages(self, request, queryset):
         actions_count = 0
@@ -761,3 +809,31 @@ class WebhookAdmin(admin.ModelAdmin):
     purge_messages.short_description = "Purge queued messages from selected webhooks"
 
     filter_horizontal = ("ping_groups",)
+
+    fieldsets = (
+        (
+            None,
+            {
+                "fields": (
+                    "name",
+                    "url",
+                    "notes",
+                    "notification_types",
+                    "ping_groups",
+                    "is_active",
+                    "is_default",
+                )
+            },
+        ),
+        (
+            "Advanced Options",
+            {
+                "classes": ("collapse",),
+                "fields": (
+                    "language_code",
+                    "has_default_pings_enabled",
+                    "webhook_type",
+                ),
+            },
+        ),
+    )
