@@ -9,7 +9,7 @@ from allianceauth.services.tasks import QueueOnce
 
 from . import __title__
 from .app_settings import STRUCTURES_TASKS_TIME_LIMIT
-from .utils import LoggerAddTag
+from app_utils.logging import LoggerAddTag
 from .models import EveSovereigntyMap, Notification, Owner, Webhook
 
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
@@ -94,15 +94,15 @@ def send_notifications(notification_pks: list) -> None:
             )
         )
         webhooks = set()
-        for n in notifications:
-            for webhook in n.owner.webhooks.filter(is_active=True):
+        for notif in notifications:
+            for webhook in notif.owner.webhooks.filter(is_active=True):
                 webhooks.add(webhook)
                 if (
-                    str(n.notification_type) in webhook.notification_types
-                    and not n.filter_for_npc_attacks()
-                    and not n.filter_for_alliance_level()
+                    str(notif.notif_type) in webhook.notification_types
+                    and not notif.filter_for_npc_attacks()
+                    and not notif.filter_for_alliance_level()
                 ):
-                    n.send_to_webhook(webhook)
+                    notif.send_to_webhook(webhook)
 
         for webhook in webhooks:
             send_messages_for_webhook.apply_async(
